-- Filename:     sin_gen.vhd
-- Filetype:     VHDL Design File
-- Date:         11 feb 2012
-- Update:       Added numeric_std for count
-- Description:  Digital Sine Wave Generator
-- Author:       J. op den Brouw
-- State:        demo
-- Error:        -
-- Version:      1.0.1
-- Copyright:    (c)2012, De Haagse Hogeschool

library ieee;
use ieee.std_logic_1164.all;
-- For use of the type unsigned
use ieee.numeric_std.all;

-- The entity
entity sin_gen is
	port (clk   : in std_logic;
			areset : in std_logic;
			sinq  : out std_logic_vector(3 downto 0)
		  );
end sin_gen;

architecture rtl of sin_gen is
-- Signal count is of type unsigned
signal count : unsigned(3 downto 0);
begin

	-- This process describes the 4 bit counter.
	-- The counter cycles cyclic from 0 to 15 and
	-- then start over again.
	cntr: process (clk, areset) is
	begin
		if areset = '1' then
			count <= "0000";
		elsif rising_edge(clk) then
			count <= count + 1;
		end if;
	end process;

	-- This process describes the ROM table
	-- with the sine signal values. It is
	-- purely combinational logic.
	sintbl: process (count) is
	begin
		case count is
			when "0000" => sinq <= "1000";
			when "0001" => sinq <= "1011";
			when "0010" => sinq <= "1101";
			when "0011" => sinq <= "1110";
			when "0100" => sinq <= "1111";
			when "0101" => sinq <= "1110";
			when "0110" => sinq <= "1101";
			when "0111" => sinq <= "1011";
			when "1000" => sinq <= "1000";
			when "1001" => sinq <= "0101";
			when "1010" => sinq <= "0011";
			when "1011" => sinq <= "0010";
			when "1100" => sinq <= "0001";
			when "1101" => sinq <= "0010";
			when "1110" => sinq <= "0011";
			when "1111" => sinq <= "0101";
			when others => sinq <= "XXXX";
		end case;
	end process;
	
end rtl;

architecture rtl_integers of sin_gen is
-- Create array with the sinus tabulated
type sin_array_type is array (0 to 15) of integer;
constant sin_array : sin_array_type := (8,11,13,14,15,14,13,11,8,5,3,2,1,2,3,5);
-- Signal count is of type integer
signal count : integer range 0 to 15;
begin
	cntr: process (clk, areset) is
	begin
		if areset = '1' then
			count <= 0;
		elsif rising_edge(clk) then
			-- Explicit test for simulation
			if count = 15 then
				count <= 0;
			else
				count <= count + 1;
			end if;
		end if;
	end process;
	
	sinq <= std_logic_vector(to_unsigned(sin_array(count),4));
end architecture rtl_integers;