# Filename:     tb_sin_gen.do
# Filetype:     Modelsim Script File
# Date:         5 december 2012
# Update:       -
# Description:  Script file voor automatische simulatie
# Author:       J. op den Brouw
# State:        demo
# Error:        -
# Version:      1.1
# Copyright:    (c)2012, De Haagse Hogeschool

# Transcript window
transcript on

# Recreate the RTL work directory
if {[file exists rtl_work]} {
	vdel -lib rtl_work -all
}
vlib rtl_work
vmap work rtl_work

# Find out if we're started through Quartus or by hand
# (or by using an exec in the Tcl window in Quartus).
# Quartus has the annoying property that it will start
# Modelsim from a directory called "simulation/modelsim".
# The design and the testbench are located in the project
# root, so we've to compensate for that.
if [ string match "*simulation/modelsim" [pwd] ] { 
	set prefix "../../"
	puts "Running Modelsim from Quartus..."
} else {
	set prefix ""
	puts "Running Modelsim..."
}

# Compile the sin_gen VHDL description and testbench,
# please note that the design and its testbench is located
# in the project root, but the simulator start in directory
# <project_root>/simulation/modelsim, so we have to compensate
# for that.
vcom -2008 -work work ${prefix}sin_gen.vhd
vcom -2008 -work work ${prefix}tb_sin_gen.vhd

# Start simulation with 1 ns time step
vsim -t 1ns -L rtl_work -L work -voptargs="+acc" tb_sin_gen

# Number of signals is small. So log them all
add log -r *

# Add all toplevel signals
add list *

# Add all toplevel signals
# Add a number of signals of the simulated design
add wave -divider "Inputs"
add wave areset
add wave clk
add wave -divider "Internals"
add wave dut/count
add wave -divider "Outputs"
add wave sinq
# Add the digitized sine as an analog signal to the Wave window
add wave -format analog-step -radix unsigned -min 0 -max 15 -height 100 sinq

# Open Structure, Wave(form) and List window
view structure
view list
view wave

# Run simulation for 4000 ns
run 4000 ns

# Fill up the waveform in the window
wave zoom full
