-- Filename:     tb_sin_gen.vhd
-- Filetype:     VHDL Testbench File
-- Date:         11 feb 2012
-- Update:       -
-- Description:  Testbench for sin_gen.vhd
-- Author:       J. op den Brouw
-- State:        demo
-- Error:        -
-- Version:      1.0
-- Copyright:    (c)2012, De Haagse Hogeschool

library ieee;                                               
use ieee.std_logic_1164.all;                                

-- The empty testbench entity
entity tb_sin_gen is
end tb_sin_gen;


architecture testbench of tb_sin_gen is
-- Signals we want to monitor
signal areset : std_logic;
signal clk : std_logic;
signal sinq : std_logic_vector(3 downto 0);

-- Declaration of the sine generator
component sin_gen
	port (areset : in std_logic;
			clk : in std_logic;
			sinq : out std_logic_vector(3 downto 0)
			);
end component;

begin

	-- Instantiation of the sine wave generator
	dut : sin_gen
	port map (
		areset => areset,
		clk => clk,
		sinq => sinq
	);

	-- This process generates the stimuli for
	-- simulation of the sine wave generator.
	gen : process
	begin
		-- First, reset the lot...
		areset <= '1';
		clk <= '0';
		wait for 100 ns;
		areset <= '0';
		wait for 200 ns;
		
		-- Generate 16 clock pulses so the sine wave
		-- generator generates exactly one period.
		for i in 0 to 15 loop
			clk <= '1';
			wait for 100 ns;
			clk <= '0';
			wait for 100 ns;
		end loop;
		
		-- Wait forever...
		wait;                                                        
	end process gen;                                          

end testbench;
